# Welcome to trio-bybit

This is an unofficial Python wrapper for the [Bybit exchange API v5](https://bybit-exchange.github.io/docs/v5/intro). I am in no way affiliated with Bybit, use at your own risk.

This repository has only async client, and works **only** with [trio]( https://trio.readthedocs.io/en/stable/index.html) or [trio-compatible](https://trio.readthedocs.io/en/stable/awesome-trio-libraries.html#trio-asyncio-interoperability) asynchronous frameworks, for example, [anyio](https://github.com/agronholm/anyio).

## Quick Start

Sign up an account with [Bybit](https://www.bybit.com/).

Generate an API key pair and assign relevant permissions.

    pip install trio-bybit

## Example

Check pytest file under ``tests``.

## Donate

If this library helps, feel free to donate.

- SOL: EbQ9Vw7QcuX6x3MxXhh34xGA9gV4kC6QVREZy7WGDuAW
